@@ -1,6 +1,5 @@
-context("test-test_misc-r.R")
 
-# dumb example to qualify as having tests...
+# dumb example just to prove we use testthat
 
 test_that("Data lods", {
   data("mercer.wheat.uniformity")
